
function PARAMS = V_ROI_Params_PAR(PARAMS)

ROIs_fullTraces_DenRaw = PARAMS(30).value;
nROIs = PARAMS(16).value;
NSweeps = PARAMS(2).value;
Sweep_L = PARAMS(3).value;
ROIs_AP_IDXs = PARAMS(27).value;

ROIs_sweeps_DenRaw = reshape(ROIs_fullTraces_DenRaw,Sweep_L,(nROIs*NSweeps));
ROIs_sweeps_DenRaw(1,:) = ROIs_sweeps_DenRaw(3,:); % remove value in point 1
ROIs_sweeps_DenRaw(2,:) = ROIs_sweeps_DenRaw(4,:); % remove value in point 2

Avg_sweep = mean(ROIs_sweeps_DenRaw,2);
Avg_sweep_based = Avg_sweep - mean(Avg_sweep);
Avg_sweep_based = highpass(Avg_sweep_based,5,600);
BlueSpike = V_APdet_noplot_blue(Avg_sweep_based,0.3);

% replace BlueSpikes and +1/-1 with avg of points so it won't introduce a
% repetitive artefact-like pattern
for i = 1:numel(BlueSpike)
    blue = BlueSpike(i);
    fill_blue = mean(ROIs_sweeps_DenRaw(blue-5:blue-2,:));
    ROIs_sweeps_DenRaw(blue,:) = fill_blue;
    fill_blue_bef = mean(ROIs_sweeps_DenRaw(blue-5:blue-3,:));
    ROIs_sweeps_DenRaw(blue-1,:) = fill_blue_bef;
    fill_blue_aft = mean(ROIs_sweeps_DenRaw(blue-4:blue-2,:));
    ROIs_sweeps_DenRaw(blue+1,:) = fill_blue_aft;
end

sweep_bef = (1:min(BlueSpike)-3)';
sweep_stim = (min(BlueSpike)-2:max(BlueSpike)+30)';
sweep_aft = ((max(BlueSpike)+31):Sweep_L)';

% Fit whole (bef,stim,aft) DenRaw traces with Poly2 to detect burst and PSP and overlay the
% "bef" baseline with poly3 so that noise level is calculated well on the
% negative part of the baseline;

warning('off');
X_fit = [sweep_bef; sweep_aft];
Xs = (1:Sweep_L);
ROIs_sweeps_DenRaw_dff = zeros(size(ROIs_sweeps_DenRaw));
 for i = 1:nROIs*NSweeps
    denraw_sweep = ROIs_sweeps_DenRaw(:,i);
    y = denraw_sweep(X_fit);
    f = fit(X_fit,y,'poly2');
    fit_values = f(Xs);
    denraw_sweep_fit = denraw_sweep - fit_values;
    denraw_sweep_dff = denraw_sweep_fit./fit_values;
    ROIs_sweeps_DenRaw_dff(:,i) = denraw_sweep_dff*-1;
 end
 
 DenRaw_sweeps_bef = ROIs_sweeps_DenRaw(sweep_bef,:);
 warning('off');
 Denraw_bef_dff = zeros(size(DenRaw_sweeps_bef));
 X_f_b = (1:size(DenRaw_sweeps_bef,1))';
 for i = 1:nROIs*NSweeps
    denraw_sweep = DenRaw_sweeps_bef(:,i);
    y = denraw_sweep(X_f_b);
    f = fit(X_f_b,y,'poly3');
    fit_values = f(X_f_b);
    denraw_sweep_fit = denraw_sweep - fit_values;
    denraw_sweep_dff = denraw_sweep_fit./fit_values;
    Denraw_bef_dff(:,i) = denraw_sweep_dff*-1;
 end
 
DenRaw_sweeps_dff_poly2 = ROIs_sweeps_DenRaw_dff;
DenRaw_sweeps_dff_poly2(sweep_bef,:) = Denraw_bef_dff;

ROIs_fullTraces_dff_poly2 = reshape(DenRaw_sweeps_dff_poly2,Sweep_L*NSweeps,nROIs);

%%
% Filter the false positive AP peak detections and keep only the ones above
% the moving mean estimated "subthreshold" activity threshold - 07.19 video
% 22 good example

ROIs_sweeps_DenRaw_dff_move_10 = movmean(DenRaw_sweeps_dff_poly2,10,1);
ROIs_sweeps_DenRaw_dff_move_100 = movmean(DenRaw_sweeps_dff_poly2,100,1);

ROIs_AP_IDXs_MoveFilt = cell(nROIs,1);
ROIs_AP_Vals_MoveFilt = cell(nROIs,1);
ROIs_123_AP_IDXs = cell(nROIs,1);
ROIs_123_AP_Vals = cell(nROIs,1);
ROIs_123_ISI_Lengths = cell(nROIs,1);
ROIs_123_ISIs_Freqs = cell(nROIs,1);
ROIs_123_ISI_Mid_IDXs = cell(nROIs,1);
ROIs_123_ISI_Mid_Vals = cell(nROIs,1);
ROIs_123_ISI_Min_IDXs = cell(nROIs,1);
ROIs_123_ISI_Min_Vals = cell(nROIs,1);
ROIs_123_Avg_Freqs = cell(nROIs,1);
ROIs_Binary_BURST = cell(nROIs,1);
ROIs_Binary_BURST_Fix = cell(nROIs,1);
ROIs_12345_BURST_Nums = cell(nROIs,1);
ROIs_12345_BURST_Lengths = cell(nROIs,1);
ROIs_12345_BURST_Firing_Freqs = cell(nROIs,1);
ROIS_APS_IN_BURST = cell(nROIs,1);

for i = 1:nROIs
    if i == round(nROIs*0.2)
        multiWaitbar('Firing and Burst analysis...',0.2,'Color', [0.929 0.694 0.125]);
          elseif i == round(nROIs*0.4)
        multiWaitbar('Firing and Burst analysis...',0.4,'Color', [0.929 0.694 0.125]);
          elseif i == round(nROIs*0.6)
        multiWaitbar('Firing and Burst analysis...',0.6,'Color', [0.929 0.694 0.125]);
          elseif i == round(nROIs*0.8)
        multiWaitbar('Firing and Burst analysis...',0.8,'Color', [0.929 0.694 0.125]);
          elseif i == nROIs
        multiWaitbar('Firing and Burst analysis...',1,'Color', [0.929 0.694 0.125]);
    end

     roi_co1_idx = ((i*NSweeps+1)-NSweeps : i*NSweeps);
     ROI_sweeps_dff = DenRaw_sweeps_dff_poly2(:,roi_co1_idx);                   % poly2 fitted DenRaw traces                          % value for Binary burst plot
     ROI_sweeps_dff_move_10 = ROIs_sweeps_DenRaw_dff_move_10(:,roi_co1_idx);    % AP detection filter moving avg
     ROI_sweeps_dff_move_100 = ROIs_sweeps_DenRaw_dff_move_100(:,roi_co1_idx);  % burst detecting moving avg
     

     ROI_ap_times = ROIs_AP_IDXs(i,1);
     ROI_ap_times = ROI_ap_times{1};
     ROI_AP_Times = cell2mat(ROI_ap_times);
        
        AP_Idxs_MoveFilt = zeros(size(ROI_AP_Times));
        AP_vals_MoveFilt = zeros(size(ROI_AP_Times));
        ROI_123_aps = cell(3,NSweeps);
        ROI_123_isis = cell(3,NSweeps);
        ROI_123_isis_mid_times = cell(3,NSweeps);
        ROI_123_isis_mid_vals = cell(3,NSweeps);
        ROI_123_isis_min_vals = cell(3,NSweeps);
        ROI_123_isis_min_idxs = cell(3,NSweeps);
        ROI_123_isis_freqs = cell(3,NSweeps);
        ROI_123_vals = cell(3,NSweeps);
        ROI_123_avg_freq = cell(3,NSweeps);
        ROI_Binary_Burst = zeros(Sweep_L,NSweeps);
        ROI_Binary_Burst_fix = zeros(Sweep_L,NSweeps);
        ROI_Burst_Nums = zeros(5,NSweeps);
        ROI_Burst_Lengths = zeros(5,NSweeps);
        ROI_Burst_Firing = zeros(5,NSweeps);
        ROI_Burst_APs_num = zeros(5,NSweeps);
        ROI_APs_in_Burst = zeros(1,NSweeps);

        for j = 1:NSweeps
            Binary_burst(1:Sweep_L) = 0;                    % burst is added in bef-stim-aft
            denraw_sweep = ROI_sweeps_dff(:,j);             % sweep to analyze
            sweep_move_10 = ROI_sweeps_dff_move_10(:,j);    % For filtering APs
            sweep_move_100 = ROI_sweeps_dff_move_100(:,j);  % For finding bursts
            
            % Filter detected APs------------------------------------------
            AP_idxs = ROI_AP_Times(:,j);
            AP_idxs = AP_idxs(AP_idxs > 0);
            AP_vals = denraw_sweep(AP_idxs);
            
            move_avg_vals = sweep_move_10(AP_idxs,:);
            AP_idxs_filt = AP_idxs(AP_vals > move_avg_vals); % AP peaks are accepted if above the move_10
            AP_vals_filt = denraw_sweep(AP_idxs_filt);
            AP_idxs_filt_pad = padarray(AP_idxs_filt,length(ROI_AP_Times)-length(AP_idxs_filt),NaN,'post');
            AP_vals_filt_pad = padarray(AP_vals_filt,length(ROI_AP_Times)-length(AP_vals_filt),NaN,'post');
            AP_Idxs_MoveFilt(:,j) = AP_idxs_filt_pad; % Store AP_times_Filt
            AP_vals_MoveFilt(:,j) = AP_vals_filt_pad; % Store AP_vals_Filt
            
            idx_bef = find(AP_idxs_filt <= max(sweep_bef)); 
            AP_times_bef = AP_idxs_filt(idx_bef);      % APs on bef
            idx_stim = find(AP_idxs_filt > max(sweep_bef) & AP_idxs_filt <= max(sweep_stim));
            AP_times_stim = AP_idxs_filt(idx_stim);    % APs on stim
            idx_aft = find(AP_idxs_filt > max(sweep_stim));
            AP_times_aft =  AP_idxs_filt(idx_aft);     % APs on aft
            
            AP_vals_bef = AP_vals_filt(idx_bef);        % AP vals in bef
            AP_vals_stim = AP_vals_filt(idx_stim);      % AP vals in stim
            AP_vals_aft = AP_vals_filt(idx_aft);        % AP vals in aft
            
            % BEF AP-related Parameters------------------------------------
            length_bef = (max(sweep_bef)-min(sweep_bef));
            if numel(AP_times_bef) < 2
              bef_aps(1:length_bef,:) = NaN;
              bef_isis(1:length_bef,:) = NaN;
              bef_mid_isi_times(1:length_bef,:) = NaN;
              bef_mid_isi_vals(1:length_bef,:) = NaN;
              bef_Isi_min_val(1:length_bef,:) = NaN;
              bef_Isi_min_idx(1:length_bef,:) = NaN;
              bef_isis_freqs(1:length_bef,:) = NaN;
              bef_avg_freq = NaN;
              bef_vals(1:length_bef,:) = NaN;
                            
              ROI_123_aps{1,j} = bef_aps;
              ROI_123_isis{1,j} = bef_isis;
              ROI_123_isis_mid_times{1,j} = bef_mid_isi_times;
              ROI_123_isis_mid_vals{1,j} = bef_mid_isi_vals;
              ROI_123_isis_min_vals{1,j} =  bef_Isi_min_val;
              ROI_123_isis_min_idxs{1,j} = bef_Isi_min_idx;
              ROI_123_isis_freqs{1,j} = bef_isis_freqs;
              ROI_123_avg_freq{1,j} = bef_avg_freq;
              ROI_123_vals{1,j} = bef_vals;
              
            else
              bef_aps_pad = padarray(AP_times_bef,length_bef-length(AP_times_bef),NaN,'post');
              bef_isis = diff(AP_times_bef)*1.66; % in ms
              bef_isis_pad = padarray(bef_isis,length_bef-length(bef_isis),NaN,'post');
              bef_mid_isi_times = round(AP_times_bef(1:end-1,:) + (bef_isis./2));
              bef_mid_isi_times_pad = padarray(bef_mid_isi_times,length_bef-length(bef_mid_isi_times),NaN,'post');
              bef_mid_isi_vals = sweep_move_10(bef_mid_isi_times,:);
              bef_mid_isi_vals_pad = padarray(bef_mid_isi_vals,length_bef-length(bef_mid_isi_vals),NaN,'post');
              bef_isis_freqs = 1000./bef_isis; %in Hz
              bef_isis_freqs_pad = padarray(bef_isis_freqs,length_bef-length(bef_isis_freqs),NaN,'post');
              bef_avg_freq = (1000/(length_bef*1.66))*numel(AP_times_bef);
              bef_vals = AP_vals_bef;
              bef_vals_pad = padarray(bef_vals,length_bef-length(bef_vals),NaN,'post');
              
              bef_Isi_min_val = zeros(numel(AP_times_bef),1);
              bef_Isi_min_idx = zeros(numel(AP_times_bef),1);
              for b = 1:numel(AP_times_bef)-1
                bef_isi_idx = (AP_times_bef(b)+1:AP_times_bef(b+1));
                bef_isi_min_val =  min(sweep_move_10(bef_isi_idx));
                bef_isi_min_idx = find(sweep_move_10 == bef_isi_min_val);
                bef_isi_100_val = sweep_move_100(bef_isi_min_idx);
                    if bef_isi_min_val > bef_isi_100_val
                       Binary_burst(bef_isi_idx) = 1; % this can be changed
                    end
                bef_Isi_min_val(b,:) = bef_isi_min_val;
                bef_Isi_min_idx(b,:) = bef_isi_min_idx;
              end
              bef_Isi_min_val_pad = padarray(bef_Isi_min_val,length_bef-length(bef_Isi_min_val),NaN,'post');
              bef_Isi_min_idx_pad = padarray(bef_Isi_min_idx,length_bef-length(bef_Isi_min_idx),NaN,'post');
              
              
              ROI_123_aps{1,j} = bef_aps_pad;
              ROI_123_isis{1,j} = bef_isis_pad;
              ROI_123_isis_mid_times{1,j} = bef_mid_isi_times_pad;
              ROI_123_isis_mid_vals{1,j} = bef_mid_isi_vals_pad;
              ROI_123_isis_min_vals{1,j} = bef_Isi_min_val_pad;
              ROI_123_isis_min_idxs{1,j} = bef_Isi_min_idx_pad;
              ROI_123_isis_freqs{1,j} = bef_isis_freqs_pad;
              ROI_123_avg_freq{1,j} = bef_avg_freq;
              ROI_123_vals{1,j} = bef_vals_pad;
            end
            
            % STIM AP-related Parameters-----------------------------------
            length_stim = (max(sweep_stim) - min(sweep_stim));
            if numel(AP_times_stim) < 2
              stim_aps(1:length_stim,:) = NaN;
              stim_isis(1:length_stim,:) = NaN;
              stim_mid_isi_times(1:length_stim,:) = NaN;
              stim_mid_isi_vals(1:length_stim,:) = NaN;
              stim_Isi_min_val(1:length_stim,:) = NaN;
              stim_Isi_min_idx(1:length_stim,:) = NaN;
              stim_isis_freqs(1:length_stim,:) = NaN;
              stim_avg_freq = NaN;
              stim_vals(1:length_stim,:) = NaN;
              
              ROI_123_aps{2,j} = stim_aps;
              ROI_123_isis{2,j} = stim_isis;
              ROI_123_isis_mid_times{2,j} = stim_mid_isi_times;
              ROI_123_isis_mid_vals{2,j} = stim_mid_isi_vals;
              ROI_123_isis_min_vals{2,j} = stim_Isi_min_val;
              ROI_123_isis_min_idxs{2,j} = stim_Isi_min_idx; 
              ROI_123_isis_freqs{2,j} = stim_isis_freqs;
              ROI_123_avg_freq{2,j} = stim_avg_freq;
              ROI_123_vals{2,j} = stim_vals;
            else
              
 
              stim_aps_pad = padarray(AP_times_stim,length_stim-length(AP_times_stim),NaN,'post');
              stim_isis = diff(AP_times_stim)*1.66; % in ms
              stim_isis_pad = padarray(stim_isis,length_stim-length(stim_isis),NaN,'post');
              stim_mid_isi_times = round(AP_times_stim(1:end-1,:) + (stim_isis./2));
              stim_mid_isi_times_pad = padarray(stim_mid_isi_times,length_stim-length(stim_mid_isi_times),NaN,'post');
              stim_mid_isi_vals = sweep_move_10(stim_mid_isi_times,:);
              stim_mid_isi_vals_pad = padarray(stim_mid_isi_vals,length_stim-length(stim_mid_isi_vals),NaN,'post');
              stim_isis_freqs = 1000./stim_isis; % in Hz
              stim_isis_freqs_pad = padarray(stim_isis_freqs,length_stim-length(stim_isis_freqs),NaN,'post');
              stim_avg_freq = (1000/(length_stim*1.66))*numel(AP_times_stim);
              stim_vals = AP_vals_stim;
              stim_vals_pad = padarray(stim_vals,length_stim-length(stim_vals),NaN,'post');
              
              stim_Isi_min_val = zeros(numel(AP_times_stim),1);
              stim_Isi_min_idx = zeros(numel(AP_times_stim),1);
              
              for b = 1:numel(AP_times_stim)-1
                stim_isi_idx = (AP_times_stim(b)+1:AP_times_stim(b+1));
                if numel(stim_isi_idx) > 20 %  considered to be another burst
                    continue
                end
                stim_isi_min_val =  min(sweep_move_10(stim_isi_idx));
                stim_isi_min_idx = find(sweep_move_10 == stim_isi_min_val);
                stim_isi_100_val = sweep_move_100(stim_isi_min_idx);
                    if stim_isi_min_val > stim_isi_100_val
                       Binary_burst(stim_isi_idx) = 1;  % this can be changed
                    end
                stim_Isi_min_val(b,:) = stim_isi_min_val;
                stim_Isi_min_idx(b,:) = stim_isi_min_idx;
              end
              stim_Isi_min_val_pad = padarray(stim_Isi_min_val,length_stim-length(stim_Isi_min_val),NaN,'post');
              stim_Isi_min_idx_pad = padarray(stim_Isi_min_idx,length_stim-length(stim_Isi_min_idx),NaN,'post');
              
              
              ROI_123_aps{2,j} = stim_aps_pad;
              ROI_123_isis{2,j} = stim_isis_pad;
              ROI_123_isis_mid_times{2,j} = stim_mid_isi_times_pad;
              ROI_123_isis_mid_vals{2,j} = stim_mid_isi_vals_pad;
              ROI_123_isis_min_vals{2,j} = stim_Isi_min_val_pad;
              ROI_123_isis_min_idxs{2,j} = stim_Isi_min_idx_pad;
              ROI_123_isis_freqs{2,j} = stim_isis_freqs_pad;
              ROI_123_avg_freq{2,j} = stim_avg_freq;
              ROI_123_vals{2,j} = stim_vals_pad;
            end
            
            % AFT AP-related Parameters------------------------------------
            length_aft = (max(sweep_aft)-min(sweep_aft));
            if numel(AP_times_aft) < 2
              
              aft_aps(1:length_aft,:) = NaN;
              aft_isis(1:length_aft,:) = NaN;
              aft_mid_isi_times(1:length_aft,:) = NaN;
              aft_mid_isi_vals(1:length_aft,:) = NaN;
              aft_Isi_min_val(1:length_aft,:) = NaN;
              aft_Isi_min_idx(1:length_aft,:) = NaN;
              aft_isis_freqs(1:length_aft,:) = NaN;
              aft_avg_freq = NaN;
              aft_vals(1:length_aft,:) = NaN;
              
              ROI_123_aps{3,j} = aft_aps;
              ROI_123_isis{3,j} = aft_isis;
              ROI_123_isis_mid_times{3,j} = aft_mid_isi_times;
              ROI_123_isis_mid_vals{3,j} = aft_mid_isi_vals;
              ROI_123_isis_min_vals{3,j} =  aft_Isi_min_val;
              ROI_123_isis_min_idxs{3,j} = aft_Isi_min_idx;
              ROI_123_isis_freqs{3,j} = aft_isis_freqs;
              ROI_123_avg_freq{3,j} = aft_avg_freq;
              ROI_123_vals{3,j} = aft_vals;
              else
              aft_aps_pad = padarray(AP_times_aft,length_aft-length(AP_times_aft),NaN,'post');
              aft_isis = diff(AP_times_aft)*1.66; % in ms
              aft_isis_pad = padarray(aft_isis,length_aft-length(aft_isis),NaN,'post');
              aft_mid_isi_times = round(AP_times_aft(1:end-1,:) + (aft_isis./2));
              aft_mid_isi_times_pad = padarray(aft_mid_isi_times,length_aft-length(aft_mid_isi_times),NaN,'post');
              aft_mid_isi_vals = sweep_move_10(aft_mid_isi_times,:);
              aft_mid_isi_vals_pad = padarray(aft_mid_isi_vals,length_aft-length(aft_mid_isi_vals),NaN,'post');
              aft_isis_freqs = 1000./aft_isis; %in Hz
              aft_isis_freqs_pad = padarray(aft_isis_freqs,length_aft-length(aft_isis_freqs),NaN,'post');
              aft_avg_freq = (1000/(length_aft*1.66))*numel(AP_times_aft);
              aft_vals = AP_vals_aft;
              aft_vals_pad = padarray(aft_vals,length_aft-length(aft_vals),NaN,'post');
              
              
              aft_Isi_min_val = zeros(numel(AP_times_aft),1);
              aft_Isi_min_idx = zeros(numel(AP_times_aft),1);
              for b = 1:numel(AP_times_aft)-1
                aft_isi_idx = (AP_times_aft(b)+1:AP_times_aft(b+1));
                aft_isi_min_val =  min(sweep_move_10(aft_isi_idx));
                aft_isi_min_idx = find(sweep_move_10 == aft_isi_min_val);
                aft_isi_100_val = sweep_move_100(aft_isi_min_idx);
                    if aft_isi_min_val > aft_isi_100_val
                       Binary_burst(aft_isi_idx) = 1;  % this can be changed
                    end
                aft_Isi_min_val(b,:) = aft_isi_min_val;
                aft_Isi_min_idx(b,:) = aft_isi_min_idx;
              end
              aft_Isi_min_val_pad = padarray(aft_Isi_min_val,length_aft-length(aft_Isi_min_val),NaN,'post');
              aft_Isi_min_idx_pad = padarray(aft_Isi_min_idx,length_aft-length(aft_Isi_min_idx),NaN,'post');
              
              
              ROI_123_aps{3,j} = aft_aps_pad;
              ROI_123_isis{3,j} = aft_isis_pad;
              ROI_123_isis_mid_times{3,j} = aft_mid_isi_times_pad;
              ROI_123_isis_mid_vals{3,j} = aft_mid_isi_vals_pad;
              ROI_123_isis_min_vals{3,j} = aft_Isi_min_val_pad;
              ROI_123_isis_min_idxs{3,j} = aft_Isi_min_idx_pad;
              ROI_123_isis_freqs{3,j} = aft_isis_freqs_pad;
              ROI_123_avg_freq{3,j} = aft_avg_freq;
              ROI_123_vals{3,j} = aft_vals_pad;
            %--------------------------------------------------------------
            % done Bef=Stim/Aft AP-related Parameters, Burst detection-----

              clear -regexp ^bef ^stim ^aft
            end

            % Find small burst interruptions (<5 points), remove short
            % non-bursts, and (<15 points), fill gap of bursts
            Binary_burst(1) = 0;
            Binary_burst(end) = 0;
            Sign_switch_sweep = find(diff(sign(Binary_burst)));
            if numel(Sign_switch_sweep) > 0
                Binary_burst_fix = Binary_burst;
                Sign_switch = find(diff(sign(Binary_burst_fix)));
                Length_sign_switch = diff(Sign_switch);
                
                % Every narrow noise is pulled to 0 or it is a gap and already 0
                noise_up = (find(Length_sign_switch < 7)); % < 7 is considered to be a false Burst
                Sign_switch_noise_from = Sign_switch(noise_up);
                Sign_switch_noise_to = Sign_switch(noise_up+1);
                for b = 1:numel(Sign_switch_noise_from)
                Points_to_switch = (Sign_switch_noise_from(b):1:Sign_switch_noise_to(b));
                Binary_burst_fix(Points_to_switch) = 0; % make small ups "burst off" 
                end
                
                % Every < 15 noise is pulled to 1 or it is already 1
                noise_down = (find(Length_sign_switch < 15)); % >15 is considered to be a new Burst
                Sign_switch_noise_from = Sign_switch(noise_down);
                Sign_switch_noise_to = Sign_switch(noise_down+1);
                for b = 1:numel(Sign_switch_noise_from)
                Points_to_switch = (Sign_switch_noise_from(b):1:Sign_switch_noise_to(b));
                Binary_burst_fix(Points_to_switch) = 1; % make small gaps "burst on" 
                end
            else
                Binary_burst_fix(1:Sweep_L) = 0;
            end
             Binary_burst_fix(1) = 0;
             Binary_burst_fix(end) = 0;

             ROI_Binary_Burst(:,j) = Binary_burst;             %save
             ROI_Binary_Burst_fix(:,j) = Binary_burst_fix;     %save
             

             % Get the number of APs in Bursts during Stim
             Burst_on = find(Binary_burst_fix == 1);
             APs_in_Burst = sum(ismember(Burst_on,AP_times_stim));
             ROI_APs_in_Burst(:,j) = APs_in_Burst/numel(AP_times_stim)*100; % in percentage
            
                   
             Burst_edges = find(diff(sign(Binary_burst_fix)));
             if isempty(Burst_edges) == 0
                Burst_onset_edges = Burst_edges(Binary_burst_fix(Burst_edges) == 0);
                Burst_offset_edges = Burst_edges(Binary_burst_fix(Burst_edges) == 1);
                Burst_num_t = numel(Burst_onset_edges); % num total
                Burst_edges_fix(1:2:numel(Burst_onset_edges)*2) = Burst_onset_edges;
                Burst_edges_fix(2:2:numel(Burst_offset_edges)*2) = Burst_offset_edges;
                Burst_onoff_edges = reshape(Burst_edges_fix,2,Burst_num_t);
                Burst_lengths = (diff(Burst_onoff_edges))*1.66; % length in ms
                %Burst_edge_interval = diff(Burst_edges_fix);
                %Burst_interval = Burst_edge_interval(2:2:end);

                Burst_Firing_freq = zeros(Burst_num_t,1);
                Burst_ap_num = zeros(Burst_num_t,1);
                for c = 1:Burst_num_t
                   onoff = Burst_onoff_edges(:,c);
                   %burst_idx = (onoff(1,:):onoff(2,:));
                   burst_length = Burst_lengths(c);
                   APs_of_burst = AP_idxs_filt(AP_idxs_filt >= onoff(1,:) & AP_idxs_filt <= onoff(2,:));
                   AP_num = numel(APs_of_burst);
                   Burst_ap_num(c,:) = AP_num;
                   burst_firing = (1000/burst_length)*AP_num;
                   Burst_Firing_freq(c,:) = burst_firing;
                end
                
                % find burst in bef,stim,aft (1,2,3,4)
                Burst_bef = find(Burst_onset_edges < max(sweep_bef));
                Burst_num_bef = numel(Burst_bef);
                Burst_lengths_bef = mean(Burst_lengths(Burst_bef));
                Burst_Firing_freq_bef = mean(Burst_Firing_freq(Burst_bef));
                Burst_APs_num = mean(Burst_lengths(Burst_bef));
                ROI_Burst_Nums(1,j) = Burst_num_bef;                %
                ROI_Burst_Lengths(1,j) = Burst_lengths_bef;         % store from Bef
                ROI_Burst_Firing(1,j) = Burst_Firing_freq_bef;      %
                ROI_Burst_APs_num(1,j) = Burst_APs_num;      %
                              
                Burst_stim_1 = find(Burst_onset_edges > max(sweep_bef) & Burst_onset_edges < (max(sweep_stim)-length_stim/2));
                Burst_num_stim_1 = numel(Burst_stim_1);               
                Burst_lengths_stim_1 = mean(Burst_lengths(Burst_stim_1));               
                Burst_Firing_freq_stim_1 = mean(Burst_Firing_freq(Burst_stim_1));
                ROI_Burst_Nums(2,j) = Burst_num_stim_1;             %
                ROI_Burst_Lengths(2,j) = Burst_lengths_stim_1;      % store from Stim 1
                ROI_Burst_Firing(2,j) = Burst_Firing_freq_stim_1;   %
                
                Burst_stim_2 = find(Burst_onset_edges > (max(sweep_stim)-length_stim/2) & Burst_onset_edges < max(sweep_stim));
                Burst_num_stim_2 = numel(Burst_stim_2);        
                Burst_lengths_stim_2 = mean(Burst_lengths(Burst_stim_2));               
                Burst_Firing_freq_stim_2 = mean(Burst_Firing_freq(Burst_stim_2));
                ROI_Burst_Nums(3,j) = Burst_num_stim_2;             %
                ROI_Burst_Lengths(3,j) = Burst_lengths_stim_2;      % store from Stim 2
                ROI_Burst_Firing(3,j) = Burst_Firing_freq_stim_2;   %
                
                Burst_aft_1 = find(Burst_onset_edges > max(sweep_stim) & Burst_onset_edges < (max(sweep_aft)-length_aft/2));
                Burst_num_aft_1 = numel(Burst_aft_1);         
                Burst_lengths_aft_1 = mean(Burst_lengths(Burst_aft_1));               
                Burst_Firing_freq_aft_1 = mean(Burst_Firing_freq(Burst_aft_1));
                ROI_Burst_Nums(4,j) = Burst_num_aft_1;              %
                ROI_Burst_Lengths(4,j) = Burst_lengths_aft_1;       % store from Aft 1
                ROI_Burst_Firing(4,j) = Burst_Firing_freq_aft_1;    %
                
                Burst_aft_2 = find(Burst_onset_edges > (max(sweep_aft)-length_aft/2));
                Burst_num_aft_2 = numel(Burst_aft_2);                
                Burst_lengths_aft_2 = mean(Burst_lengths(Burst_aft_2));                
                Burst_Firing_freq_aft_2 = mean(Burst_Firing_freq(Burst_aft_2));
                ROI_Burst_Nums(5,j) = Burst_num_aft_2;              %
                ROI_Burst_Lengths(5,j) = Burst_lengths_aft_2;       % store from Aft 2
                ROI_Burst_Firing(5,j) = Burst_Firing_freq_aft_2;    %
             else
                ROI_Burst_Nums(1:5,j) = NaN;
                ROI_Burst_Lengths(1:5,j) = NaN;
                ROI_Burst_Firing(1:5,j) = NaN;
             end
             
             clear -regexp ^Burst
             
        end % end of sweep analysis

        ROIs_AP_IDXs_MoveFilt{i} = AP_Idxs_MoveFilt;
        ROIs_AP_Vals_MoveFilt{i} = AP_vals_MoveFilt;
        ROIs_123_AP_IDXs{i} = ROI_123_aps;
        ROIs_123_AP_Vals{i} = ROI_123_vals;
        ROIs_123_ISI_Lengths{i} = ROI_123_isis;
        ROIs_123_ISIs_Freqs{i} = ROI_123_isis_freqs;
        ROIs_123_ISI_Mid_IDXs{i} = ROI_123_isis_mid_times;
        ROIs_123_ISI_Mid_Vals{i} = ROI_123_isis_mid_vals;
        ROIs_123_ISI_Min_IDXs{i} = ROI_123_isis_min_idxs;
        ROIs_123_ISI_Min_Vals{i} = ROI_123_isis_min_vals;
        ROIs_123_Avg_Freqs{i} = ROI_123_avg_freq;
        ROIs_Binary_BURST{i} = ROI_Binary_Burst;
        ROIs_Binary_BURST_Fix{i} = ROI_Binary_Burst_fix;
        ROIs_12345_BURST_Nums{i} = ROI_Burst_Nums;
        ROIs_12345_BURST_Lengths{i} = ROI_Burst_Lengths;
        ROIs_12345_BURST_Firing_Freqs{i} = ROI_Burst_Firing;
        ROIS_APS_IN_BURST{i} = ROI_APs_in_Burst;
end


PARAMS(31).name = 'ROIs_sweeps_DenRaw';
PARAMS(32).name = 'ROIs_sweeps_DenRaw_dff_move_10';
PARAMS(33).name = 'ROIs_sweeps_DenRaw_dff_move_100';
PARAMS(34).name = 'DenRaw_sweeps_dff_poly2';
PARAMS(35).name = 'ROIs_fullTraces_dff_poly2';
PARAMS(36).name = 'ROIs_AP_IDXs_MoveFilt';
PARAMS(37).name = 'ROIs_AP_Vals_MoveFilt';
PARAMS(38).name = 'ROIs_123_AP_IDXs'; % Point idx
PARAMS(39).name = 'ROIs_123_AP_Vals'; % in ms
PARAMS(40).name = 'ROIs_123_ISI_Lengths'; % in Hz
PARAMS(41).name = 'ROIs_123_ISIs_Freqs'; % Point idx
PARAMS(42).name = 'ROIs_123_ISI_Mid_IDXs';
PARAMS(43).name = 'ROIs_123_ISI_Mid_Vals';
PARAMS(44).name = 'ROIs_123_ISI_Min_IDXs';
PARAMS(45).name = 'ROIs_123_ISI_Min_Vals';
PARAMS(46).name = 'ROIs_123_Avg_Freqs';
PARAMS(47).name = 'ROIs_Binary_BURST';
PARAMS(48).name = 'ROIs_Binary_BURST_Fix';
PARAMS(49).name = 'ROIs_12345_BURST_Nums';
PARAMS(50).name = 'ROIs_12345_BURST_Lengths';
PARAMS(51).name = 'ROIs_12345_BURST_Firing_Freqs';
PARAMS(52).name = 'ROIS_APS_IN_BURST';

PARAMS(31).value = ROIs_sweeps_DenRaw;
PARAMS(32).value = ROIs_sweeps_DenRaw_dff_move_10;
PARAMS(33).value = ROIs_sweeps_DenRaw_dff_move_100;
PARAMS(34).value = DenRaw_sweeps_dff_poly2;
PARAMS(35).value = ROIs_fullTraces_dff_poly2;
PARAMS(36).value = ROIs_AP_IDXs_MoveFilt;
PARAMS(37).value = ROIs_AP_Vals_MoveFilt;
PARAMS(38).value = ROIs_123_AP_IDXs; % Point idx
PARAMS(39).value = ROIs_123_AP_Vals; % in ms
PARAMS(40).value = ROIs_123_ISI_Lengths; % in Hz
PARAMS(41).value = ROIs_123_ISIs_Freqs; % Point idx
PARAMS(42).value = ROIs_123_ISI_Mid_IDXs;
PARAMS(43).value = ROIs_123_ISI_Mid_Vals;
PARAMS(44).value = ROIs_123_ISI_Min_IDXs;
PARAMS(45).value = ROIs_123_ISI_Min_Vals;
PARAMS(46).value = ROIs_123_Avg_Freqs;
PARAMS(47).value = ROIs_Binary_BURST;
PARAMS(48).value = ROIs_Binary_BURST_Fix;
PARAMS(49).value = ROIs_12345_BURST_Nums;
PARAMS(50).value = ROIs_12345_BURST_Lengths;
PARAMS(51).value = ROIs_12345_BURST_Firing_Freqs;
PARAMS(52).value = ROIS_APS_IN_BURST;


end

